# CHANGELOG

## 0.4

> 📅 **Date** 2024-6-1

- 🆕 New Features:
  - Add `py.typed` file, make the package PEP-561 friendly

- Better type hints
- Some optimizations and bugfix

## 0.4rc1

> 📅 **Date** 2024-3-15

## 0.3

| Version | 0.3       |
| ------- | --------- |
| Date    | 2023-4-25 |

- Change:
  - Python >= 3.7 required now.
- Misc:
  - Improve CI

## 0.2.2

| Version | 0.2.2      |
| ------- | ---------- |
| Date    | 2021-11-21 |

## 0.2.1

| Version | 0.2.1      |
| ------- | ---------- |
| Date    | 2021-11-05 |

- New Features:
  - update to PyYAML 6.0

## 0.2

- Date: 2021-09-08

- new api
- update to Jinja2 3.0

## 0.2a1

Many APIs changed in `v0.2`

## v0.1

An early version, maybe not stable enough.
